@@ -26,18 +26,16 @@ import re
 import stat
 import time
 
-from ironic_lib.common.i18n import _
-from ironic_lib import exception
-from ironic_lib import utils
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_utils import excutils
+from oslo_utils.imageutils import format_inspector
 import tenacity
 
 from ironic_python_agent import disk_partitioner
 from ironic_python_agent import errors
-from ironic_python_agent import format_inspector
 from ironic_python_agent import qemu_img
+from ironic_python_agent import utils
 
 CONF = cfg.CONF
 
@@ -54,6 +52,9 @@ MAX_CONFIG_DRIVE_SIZE_MB = 64
 # Maximum disk size supported by MBR is 2TB (2 * 1024 * 1024 MB)
 MAX_DISK_SIZE_MB_SUPPORTED_BY_MBR = 2097152
 
+# NOTE(JayF): Image types we write bit-perfect to disk, no conversion
+RAW_LIKE_IMAGETYPES = ['gpt', 'raw']
+
 
 def list_partitions(device):
     """Get partitions information from given device.
@@ -149,21 +150,6 @@ def get_partition_table_type(device):
     return 'unknown'
 
 
-def _blkid(device, probe=False, fields=None):
-    args = []
-    if probe:
-        args.append('-p')
-    if fields:
-        args += sum((['-s', field] for field in fields), [])
-
-    output, err = utils.execute('blkid', device, *args,
-                                use_standard_locale=True)
-    if output.strip():
-        return output.split(': ', 1)[1]
-    else:
-        return ""
-
-
 def _lsblk(device, deps=True, fields=None):
     args = ['--pairs', '--bytes', '--ascii']
     if not deps:
@@ -374,40 +360,39 @@ def is_block_device(dev):
             time.sleep(1)
         else:
             return stat.S_ISBLK(s.st_mode)
-    msg = _("Unable to stat device %(dev)s after attempting to verify "
-            "%(attempts)d times.") % {'dev': dev, 'attempts': attempts}
+    msg = ("Unable to stat device %(dev)s after attempting to verify "
+           "%(attempts)d times.") % {'dev': dev, 'attempts': attempts}
     LOG.error(msg)
-    raise exception.InstanceDeployFailure(msg)
+    raise errors.DeploymentError(msg)
 
 
 def dd(src, dst, conv_flags=None):
     """Execute dd from src to dst."""
+    args = ['bs=%s' % CONF.disk_utils.dd_block_size, 'oflag=direct']
     if conv_flags:
-        extra_args = ['conv=%s' % conv_flags]
-    else:
-        extra_args = []
+        args.append('conv=%s' % conv_flags)
 
-    utils.dd(src, dst, 'bs=%s' % CONF.disk_utils.dd_block_size, 'oflag=direct',
-             *extra_args)
+    utils.execute('dd', 'if=%s' % src, 'of=%s' % dst, *args,
+                  use_standard_locale=True)
 
 
 def _image_inspection(filename):
     try:
         inspector_cls = format_inspector.detect_file_format(filename)
-        if (not inspector_cls
-            or not hasattr(inspector_cls, 'safety_check')
-            or not inspector_cls.safety_check()):
-            err = "Security: Image failed safety check"
-            LOG.error(err)
-            raise errors.InvalidImage(details=err)
+        if not inspector_cls:
+            msg = "Security: Unable to safety check image"
+            LOG.error(msg)
+            raise errors.InvalidImage(details=msg)
+        inspector_cls.safety_check()
 
-    except (format_inspector.ImageFormatError, AttributeError):
-        # NOTE(JayF): Because we already validated the format is OK and matches
-        #             expectation, it should be impossible for us to get an
-        #             ImageFormatError or AttributeError. We handle it anyway
-        #             for completeness.
-        msg = "Security: Unable to safety check image"
-        LOG.error(msg)
+    except format_inspector.ImageFormatError:
+        msg = "Security: Image matched multiple potential formats"
+        LOG.exception(msg)
+        raise errors.InvalidImage(details=msg)
+
+    except format_inspector.SafetyCheckFailed:
+        msg = "Security: Image failed safety check"
+        LOG.exception(msg)
         raise errors.InvalidImage(details=msg)
 
     return inspector_cls
@@ -418,10 +403,12 @@ def get_and_validate_image_format(filename, ironic_disk_format):
 
     This method uses the format inspector originally written for glance to
     safely detect the image format. It also sanity checks to ensure any
-    specified format matches the provided one (except raw; which in some
-    cases is a request to convert to raw) and that the format is in the
+    specified format matches the provided one and that the format is in the
     allowed list of formats.
 
+    If the image format provided by Ironic is a type which doesn't need
+    conversion, we avoid all introspection of the image and use of qemu-img.
+
     It also performs a basic safety check on the image.
 
     This entire process can be bypassed, and the older code path used,
@@ -439,10 +426,10 @@ def get_and_validate_image_format(filename, ironic_disk_format):
         img_format = data.file_format
         size = data.virtual_size
     else:
-        if ironic_disk_format == 'raw':
-            # NOTE(JayF): IPA unconditionally writes raw images to disk without
-            #             conversion with dd or raw python, not qemu-img, it's
-            #             not required to safety check raw images.
+        if ironic_disk_format in RAW_LIKE_IMAGETYPES:
+            # NOTE(JayF): IPA avoids converting images which claim to be a
+            #             type that doesn't need conversion. This negates any
+            #             security risk the image file could pose.
             img_format = ironic_disk_format
             size = os.path.getsize(filename)
         else:
@@ -457,7 +444,9 @@ def get_and_validate_image_format(filename, ironic_disk_format):
                 raise errors.InvalidImage(
                     details=msg % (img_format, fmts)
                 )
-            elif ironic_disk_format and ironic_disk_format != img_format:
+            elif (ironic_disk_format
+                  and ironic_disk_format != img_format
+                  and ironic_disk_format != 'unknown'):
                 msg = ("Security: Expected format was %s, but image was "
                        "actually %s" % (ironic_disk_format, img_format))
                 LOG.error(msg)
@@ -466,22 +455,37 @@ def get_and_validate_image_format(filename, ironic_disk_format):
     return img_format, size
 
 
-def populate_image(src, dst, conv_flags=None,
-                   source_format=None, is_raw=False):
+def populate_image(src, dst, conv_flags=None, source_format=None, is_raw=False,
+                   sparse_size='0', out_format='raw', **convert_args):
     """Populate a provided destination device with the image
 
     :param src: An image already security checked in format disk_format
     :param dst: A location, usually a partition or block device,
                 to write the image
     :param conv_flags: Conversion flags to pass to dd if provided
-    :param source_format: format of the image
     :param is_raw: Ironic indicates image is raw; do not convert!
+    :param sparse_size: Sparse size to pass to qemu_img
+    :param source_format: format of the image
+    :param out_format: Output format
+    :param convert_args: Additional arguments to optionally pass to qemu_img
     """
-    if is_raw:
-        dd(src, dst, conv_flags=conv_flags)
-    else:
-        qemu_img.convert_image(src, dst, 'raw', True,
-                               sparse_size='0', source_format=source_format)
+    try:
+        if is_raw:
+            # NOTE(JayF): Since we do not safety check raw images, we must use
+            #  dd to write them to ensure maximum security. This may cause
+            #  failures in situations where images are configured as raw but
+            #  are actually in need of conversion. Those cases can no longer
+            #  be transparently handled safely.
+            LOG.info('Writing raw image %s to device %s', src, dst)
+            dd(src, dst, conv_flags=conv_flags)
+        else:
+            qemu_img.convert_image(src, dst,
+                                   out_format=out_format,
+                                   sparse_size=sparse_size,
+                                   source_format=source_format,
+                                   **convert_args)
+    except processutils.ProcessExecutionError as e:
+        raise errors.ImageWriteError(dst, e.exit_code, e.stdout, e.stderr)
 
 
 def block_uuid(dev):
@@ -575,14 +579,12 @@ def destroy_disk_metadata(dev, node_uuid):
 
     try:
         wait_for_disk_to_become_available(dev)
-    except exception.IronicException as e:
-        raise exception.InstanceDeployFailure(
-            _('Destroying metadata failed on device %(device)s. '
-              'Error: %(error)s')
-            % {'device': dev, 'error': e})
+    except errors.RESTError as e:
+        raise errors.DeploymentError(
+            f'Destroying metadata failed on device {dev}s. Error: {e}')
 
-    LOG.info("Disk metadata on %(dev)s successfully destroyed for node "
-             "%(node)s", {'dev': dev, 'node': node_uuid})
+    LOG.info("Disk metadata on %s successfully destroyed for node "
+             "%s", dev, node_uuid)
 
 
 def _fix_gpt_structs(device, node_uuid):
@@ -601,11 +603,11 @@ def _fix_gpt_structs(device, node_uuid):
             utils.execute('sgdisk', '-e', device)
     except (processutils.UnknownArgumentError,
             processutils.ProcessExecutionError, OSError) as e:
-        msg = (_('Failed to fix GPT data structures on disk %(disk)s '
-                 'for node %(node)s. Error: %(error)s') %
+        msg = ('Failed to fix GPT data structures on disk %(disk)s '
+               'for node %(node)s. Error: %(error)s' %
                {'disk': device, 'node': node_uuid, 'error': e})
         LOG.error(msg)
-        raise exception.InstanceDeployFailure(msg)
+        raise errors.DeploymentError(msg)
 
 
 def fix_gpt_partition(device, node_uuid):
@@ -623,11 +625,11 @@ def fix_gpt_partition(device, node_uuid):
         if disk_is_gpt_partitioned:
             _fix_gpt_structs(device, node_uuid)
     except Exception as e:
-        msg = (_('Failed to fix GPT partition on disk %(disk)s '
-                 'for node %(node)s. Error: %(error)s') %
+        msg = ('Failed to fix GPT partition on disk %(disk)s '
+               'for node %(node)s. Error: %(error)s' %
                {'disk': device, 'node': node_uuid, 'error': e})
         LOG.error(msg)
-        raise exception.InstanceDeployFailure(msg)
+        raise errors.DeploymentError(msg)
 
 
 def udev_settle():
@@ -713,8 +715,6 @@ def trigger_device_rescan(device, attempts=None):
         return True
 
 
-# NOTE(dtantsur): this function was in ironic_lib.utils before migration
-# (presumably to avoid a circular dependency with disk_partitioner)
 def wait_for_disk_to_become_available(device):
     """Wait for a disk device to become available.
 
@@ -784,14 +784,13 @@ def wait_for_disk_to_become_available(device):
         retry(_wait_for_disk)()
     except tenacity.RetryError:
         if pids[0]:
-            raise exception.IronicException(
-                _('Processes with the following PIDs are holding '
-                  'device %(device)s: %(pids)s. '
-                  'Timed out waiting for completion.')
+            raise errors.DeviceNotFound(
+                ('Processes with the following PIDs are holding '
+                 'device %(device)s: %(pids)s. '
+                 'Timed out waiting for completion.')
                 % {'device': device, 'pids': ', '.join(pids[0])})
         else:
-            raise exception.IronicException(
-                _('Fuser exited with "%(fuser_err)s" while checking '
-                  'locks for device %(device)s. Timed out waiting for '
-                  'completion.')
-                % {'device': device, 'fuser_err': stderr[0]})
+            raise errors.DeviceNotFound(
+                ('Fuser exited with "%(fuser_err)s" while checking '
+                 'locks for device %(device)s. Timed out waiting for '
+                 'completion.') % {'device': device, 'fuser_err': stderr[0]})
