@@ -40,7 +40,7 @@ from ironic_python_agent import hardware
 from ironic_python_agent import utils
 
 
-LOG = log.getLogger()
+LOG = log.getLogger(__name__)
 CONF = cfg.CONF
 
 MAX_CONFIG_DRIVE_SIZE_MB = 64
