@@ -18,18 +18,17 @@ import os
 import stat
 from unittest import mock
 
-from ironic_lib import exception
-from ironic_lib.tests import base
-from ironic_lib import utils
 from oslo_concurrency import processutils
 from oslo_config import cfg
+from oslo_utils.imageutils import format_inspector
 from oslo_utils.imageutils import QemuImgInfo
 from oslo_utils import units
 
 from ironic_python_agent import disk_utils
-from ironic_python_agent.errors import InvalidImage
-from ironic_python_agent import format_inspector
+from ironic_python_agent import errors
 from ironic_python_agent import qemu_img
+from ironic_python_agent.tests.unit import base
+from ironic_python_agent import utils
 
 CONF = cfg.CONF
 
@@ -53,7 +52,12 @@ class MockFormatInspectorCls(object):
             return (self.virtual_size_mb * units.Mi) + 1 - units.Mi
 
     def safety_check(self):
-        return self.safe
+        if self.safe:
+            return True
+        else:
+            raise format_inspector.SafetyCheckFailed(
+                failures={'mockfail': format_inspector.SafetyViolation()}
+            )
 
 
 def _get_fake_qemu_image_info(file_format='qcow2', virtual_size=0):
@@ -62,7 +66,7 @@ def _get_fake_qemu_image_info(file_format='qcow2', virtual_size=0):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class ListPartitionsTestCase(base.IronicLibTestCase):
+class ListPartitionsTestCase(base.IronicAgentTest):
 
     def test_correct(self, execute_mock):
         output = """
@@ -137,7 +141,7 @@ BYT;
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class MakePartitionsTestCase(base.IronicLibTestCase):
+class MakePartitionsTestCase(base.IronicAgentTest):
 
     def setUp(self):
         super(MakePartitionsTestCase, self).setUp()
@@ -337,7 +341,7 @@ class MakePartitionsTestCase(base.IronicLibTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class DestroyMetaDataTestCase(base.IronicLibTestCase):
+class DestroyMetaDataTestCase(base.IronicAgentTest):
 
     def setUp(self):
         super(DestroyMetaDataTestCase, self).setUp()
@@ -501,7 +505,7 @@ class DestroyMetaDataTestCase(base.IronicLibTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class GetDeviceByteSizeTestCase(base.IronicLibTestCase):
+class GetDeviceByteSizeTestCase(base.IronicAgentTest):
 
     def setUp(self):
         super(GetDeviceByteSizeTestCase, self).setUp()
@@ -517,7 +521,7 @@ class GetDeviceByteSizeTestCase(base.IronicLibTestCase):
 
 @mock.patch.object(disk_utils, 'dd', autospec=True)
 @mock.patch.object(qemu_img, 'convert_image', autospec=True)
-class PopulateImageTestCase(base.IronicLibTestCase):
+class PopulateImageTestCase(base.IronicAgentTest):
 
     def test_populate_raw_image(self, mock_cg, mock_dd):
         source_format = 'raw'
@@ -531,14 +535,15 @@ class PopulateImageTestCase(base.IronicLibTestCase):
         source_format = 'qcow2'
         disk_utils.populate_image('src', 'dst',
                                   source_format=source_format, is_raw=False)
-        mock_cg.assert_called_once_with('src', 'dst', 'raw', True,
+        mock_cg.assert_called_once_with('src', 'dst',
+                                        out_format='raw',
                                         sparse_size='0',
                                         source_format=source_format)
         self.assertFalse(mock_dd.called)
 
 
 @mock.patch('time.sleep', lambda sec: None)
-class OtherFunctionTestCase(base.IronicLibTestCase):
+class OtherFunctionTestCase(base.IronicAgentTest):
 
     @mock.patch.object(os, 'stat', autospec=True)
     @mock.patch.object(stat, 'S_ISBLK', autospec=True)
@@ -553,7 +558,7 @@ class OtherFunctionTestCase(base.IronicLibTestCase):
     def test_is_block_device_raises(self, mock_os):
         device = '/dev/disk/by-path/ip-1.2.3.4:5678-iscsi-iqn.fake-lun-9'
         mock_os.side_effect = OSError
-        self.assertRaises(exception.InstanceDeployFailure,
+        self.assertRaises(errors.DeploymentError,
                           disk_utils.is_block_device, device)
         mock_os.assert_has_calls([mock.call(device)] * 3)
 
@@ -563,7 +568,7 @@ class OtherFunctionTestCase(base.IronicLibTestCase):
                           group='disk_utils')
         device = '/dev/disk/by-path/ip-1.2.3.4:5678-iscsi-iqn.fake-lun-9'
         mock_os.side_effect = OSError
-        self.assertRaises(exception.InstanceDeployFailure,
+        self.assertRaises(errors.DeploymentError,
                           disk_utils.is_block_device, device)
         mock_os.assert_has_calls([mock.call(device)] * 2)
 
@@ -616,7 +621,7 @@ class OtherFunctionTestCase(base.IronicLibTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class FixGptStructsTestCases(base.IronicLibTestCase):
+class FixGptStructsTestCases(base.IronicAgentTest):
 
     def setUp(self):
         super(FixGptStructsTestCases, self).setUp()
@@ -650,7 +655,7 @@ Identified 1 problems!
     @mock.patch.object(disk_utils.LOG, 'error', autospec=True)
     def test_fix_gpt_structs_exc(self, mock_log, mock_execute):
         mock_execute.side_effect = processutils.ProcessExecutionError
-        self.assertRaisesRegex(exception.InstanceDeployFailure,
+        self.assertRaisesRegex(errors.DeploymentError,
                                'Failed to fix GPT data structures on disk',
                                disk_utils._fix_gpt_structs,
                                self.dev, self.node_uuid)
@@ -659,7 +664,7 @@ Identified 1 problems!
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class TriggerDeviceRescanTestCase(base.IronicLibTestCase):
+class TriggerDeviceRescanTestCase(base.IronicAgentTest):
     def test_trigger(self, mock_execute):
         self.assertTrue(disk_utils.trigger_device_rescan('/dev/fake'))
         mock_execute.assert_has_calls([
@@ -707,7 +712,7 @@ LSBLK_NORMAL = (
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class GetDeviceInformationTestCase(base.IronicLibTestCase):
+class GetDeviceInformationTestCase(base.IronicAgentTest):
 
     def test_normal(self, mock_execute):
         mock_execute.return_value = LSBLK_NORMAL, ""
@@ -746,7 +751,7 @@ class GetDeviceInformationTestCase(base.IronicLibTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class GetPartitionTableTypeTestCase(base.IronicLibTestCase):
+class GetPartitionTableTypeTestCase(base.IronicAgentTest):
     def test_gpt(self, mocked_execute):
         self._test_by_type(mocked_execute, 'gpt', 'gpt')
 
@@ -786,7 +791,7 @@ Number  Start   End     Size    File system  Name  Flags
 
 @mock.patch.object(disk_utils, 'list_partitions', autospec=True)
 @mock.patch.object(disk_utils, 'get_partition_table_type', autospec=True)
-class FindEfiPartitionTestCase(base.IronicLibTestCase):
+class FindEfiPartitionTestCase(base.IronicAgentTest):
 
     def test_find_efi_partition(self, mocked_type, mocked_parts):
         mocked_parts.return_value = [
@@ -826,7 +831,7 @@ class FindEfiPartitionTestCase(base.IronicLibTestCase):
         self.assertIsNone(disk_utils.find_efi_partition('/dev/sda'))
 
 
-class WaitForDisk(base.IronicLibTestCase):
+class WaitForDisk(base.IronicAgentTest):
 
     def setUp(self):
         super(WaitForDisk, self).setUp()
@@ -848,7 +853,7 @@ class WaitForDisk(base.IronicLibTestCase):
                        side_effect=processutils.ProcessExecutionError(
                            stderr='fake'))
     def test_wait_for_disk_to_become_available_no_fuser(self, mock_exc):
-        self.assertRaises(exception.IronicException,
+        self.assertRaises(errors.RESTError,
                           disk_utils.wait_for_disk_to_become_available,
                           'fake-dev')
         fuser_cmd = ['fuser', 'fake-dev']
@@ -872,7 +877,7 @@ class WaitForDisk(base.IronicLibTestCase):
                           'holding device fake-dev: 15503, 3919, 15510, '
                           '15511. Timed out waiting for completion.')
         self.assertRaisesRegex(
-            exception.IronicException,
+            errors.RESTError,
             expected_error,
             disk_utils.wait_for_disk_to_become_available,
             'fake-dev')
@@ -897,7 +902,7 @@ class WaitForDisk(base.IronicLibTestCase):
                           'holding device fake-dev: 15503, 3919, 15510, '
                           '15511. Timed out waiting for completion.')
         self.assertRaisesRegex(
-            exception.IronicException,
+            errors.RESTError,
             expected_error,
             disk_utils.wait_for_disk_to_become_available,
             'fake-dev')
@@ -919,7 +924,7 @@ class WaitForDisk(base.IronicLibTestCase):
                           'locks for device fake-dev. Timed out waiting '
                           'for completion.')
         self.assertRaisesRegex(
-            exception.IronicException,
+            errors.RESTError,
             expected_error,
             disk_utils.wait_for_disk_to_become_available,
             'fake-dev')
@@ -961,7 +966,7 @@ class WaitForDisk(base.IronicLibTestCase):
         mock_exc.assert_has_calls([fuser_call, fuser_call])
 
 
-class GetAndValidateImageFormat(base.IronicLibTestCase):
+class GetAndValidateImageFormat(base.IronicAgentTest):
     @mock.patch.object(disk_utils, '_image_inspection', autospec=True)
     @mock.patch('os.path.getsize', autospec=True)
     def test_happy_raw(self, mock_size, mock_ii):
@@ -993,7 +998,7 @@ class GetAndValidateImageFormat(base.IronicLibTestCase):
         CONF.set_override('disable_deep_image_inspection', False)
         fmt = 'qcow3'
         mock_ii.return_value = MockFormatInspectorCls(fmt, 0, True)
-        self.assertRaises(InvalidImage,
+        self.assertRaises(errors.InvalidImage,
                           disk_utils.get_and_validate_image_format,
                           '/fake/path', fmt)
         mock_ii.assert_called_once_with('/fake/path')
@@ -1004,10 +1009,22 @@ class GetAndValidateImageFormat(base.IronicLibTestCase):
         CONF.set_override('disable_deep_image_inspection', False)
         fmt = 'qcow2'
         mock_ii.return_value = MockFormatInspectorCls('qcow3', 0, True)
-        self.assertRaises(InvalidImage,
+        self.assertRaises(errors.InvalidImage,
                           disk_utils.get_and_validate_image_format,
                           '/fake/path', fmt)
 
+    @mock.patch.object(disk_utils, '_image_inspection', autospec=True)
+    def test_format_unknown_happy(self, mock_ii):
+        """ironic_disk_format=unknown, but we detect it as a qcow3"""
+        CONF.set_override('disable_deep_image_inspection', False)
+        fmt = 'unknown'
+        mock_ii.return_value = MockFormatInspectorCls('qcow2', 0, True)
+        self.assertEqual(
+            ('qcow2', 0),
+            disk_utils.get_and_validate_image_format('/fake/path', fmt)
+        )
+        mock_ii.assert_called_once_with('/fake/path')
+
     @mock.patch.object(disk_utils, '_image_inspection', autospec=True)
     @mock.patch.object(qemu_img, 'image_info', autospec=True)
     def test_format_mismatch_but_disabled(self, mock_info, mock_ii):
@@ -1041,7 +1058,7 @@ class GetAndValidateImageFormat(base.IronicLibTestCase):
         mock_info.assert_called_once()
 
 
-class ImageInspectionTest(base.IronicLibTestCase):
+class ImageInspectionTest(base.IronicAgentTest):
     @mock.patch.object(format_inspector, 'detect_file_format', autospec=True)
     def test_image_inspection_pass(self, mock_fi):
         inspector = MockFormatInspectorCls('qcow2', 0, True)
@@ -1052,11 +1069,11 @@ class ImageInspectionTest(base.IronicLibTestCase):
     def test_image_inspection_fail_safety_check(self, mock_fi):
         inspector = MockFormatInspectorCls('qcow2', 0, False)
         mock_fi.return_value = inspector
-        self.assertRaises(InvalidImage, disk_utils._image_inspection,
+        self.assertRaises(errors.InvalidImage, disk_utils._image_inspection,
                           '/fake/path')
 
     @mock.patch.object(format_inspector, 'detect_file_format', autospec=True)
     def test_image_inspection_fail_format_error(self, mock_fi):
         mock_fi.side_effect = format_inspector.ImageFormatError
-        self.assertRaises(InvalidImage, disk_utils._image_inspection,
+        self.assertRaises(errors.InvalidImage, disk_utils._image_inspection,
                           '/fake/path')
