@@ -394,3 +394,27 @@ class TestNetutils(base.IronicAgentTest):
     def test_wrap_ipv6_with_ipv4(self):
         res = netutils.wrap_ipv6('1.2.3.4')
         self.assertEqual('1.2.3.4', res)
+
+    @mock.patch('os.readlink', autospec=True)
+    def test_get_interface_pci_address(self, mock_read):
+        mock_read.return_value = '../../../0000:02:00.0'
+        addr = netutils.get_interface_pci_address('ens160')
+        self.assertEqual('0000:02:00.0', addr)
+
+    @mock.patch('os.readlink', autospec=True)
+    def test_get_interface_pci_address_notfound(self, mock_read):
+        mock_read.side_effect = FileNotFoundError
+        addr = netutils.get_interface_pci_address('ens160')
+        self.assertIsNone(addr)
+
+    @mock.patch('os.readlink', autospec=True)
+    def test_get_interface_driver(self, mock_read):
+        mock_read.return_value = '../../../../bus/pci/drivers/e1000e'
+        addr = netutils.get_interface_driver('ens160')
+        self.assertEqual('e1000e', addr)
+
+    @mock.patch('os.readlink', autospec=True)
+    def test_get_interface_driver_notfound(self, mock_read):
+        mock_read.side_effect = FileNotFoundError
+        driver = netutils.get_interface_driver('ens160')
+        self.assertIsNone(driver)
